@@ -15,5 +15,5 @@
 
 
 from .handler import queue_handler
-from .process import execute
 from .mpcurses import MPcurses
+from .mpcontroller import MPcontroller
